﻿using System;
using System.IO;
using System.Reflection;
using System.Text;
using System.Threading;
using System.Windows.Forms;
using Timer = System.Windows.Forms.Timer;

namespace HiroExemploCSharp
{
    public partial class Home : Form
    {
        //private ToolTip toolTip;
        private Exemplo exemplo;
        private Timer timer;

        public Home()
        {
            InitializeComponent();
            this.exemplo = new Exemplo();
            this.timer = new Timer();
            this.timer.Tick += timer_Tick;
        }

        void timer_Tick(object sender, EventArgs e)
        {
            try
            {
                var data = this.exemplo.GetRelogioConcentradorTest();
                if (!data.ToString().Equals("01/01/0001 00:00:00"))
                {
                    this.txtPoolRelogio.Text += string.Format("Data :{0}. \r\n", data);
                }
                Thread.Sleep(1000);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void btnConectarSerial_Click(object sender, EventArgs e)
        {
            this.exemplo.SetComunicacaoSerial(this.txtPorta.Text);
        }

        private void btnConectarUSB_Click(object sender, EventArgs e)
        {
            this.exemplo.SetComunicacaoUSB();
        }

        private void btnConectarTCP_Click(object sender, EventArgs e)
        {
            this.exemplo.SetComunicacaoTCP(this.txtIP.Text,
                                           this.txtPorta.Text,
                                           this.txtMascara.Text,
                                           this.txtDNS.Text,
                                           this.txtGateway.Text,
                                           this.chbDHCP.Checked);
        }

        private void btnStartFirmware_Click(object sender, EventArgs e)
        {
            try
            {
                this.exemplo.StartGravacaoFirmwareTest(this.txtCaminhoFirmware.Text);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void btnEnviarFirmware_Click(object sender, EventArgs e)
        {
            try
            {
                this.exemplo.SendPacoteFirmwareTest(this.txtCaminhoFirmware.Text);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void btnStopFirmware_Click(object sender, EventArgs e)
        {
            try
            {
                this.exemplo.StopGravacaoFirmwareTest();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void btnExecuteFirmware_Click(object sender, EventArgs e)
        {
            try
            {
                this.exemplo.ExecuteFirmwareTest();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void tsbStart_Click(object sender, EventArgs e)
        {
            this.timer.Start();
        }

        private void tsbPause_Click(object sender, EventArgs e)
        {
            this.timer.Stop();
        }

        private void tsbRefresh_Click(object sender, EventArgs e)
        {
            this.txtPoolRelogio.Text = string.Empty;
        }

        private void tsbSetRelogio_Click(object sender, EventArgs e)
        {
            try
            {
                this.exemplo.SetRelogioConcentradorTest();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            try
            {
                MessageBox.Show(this.exemplo.TestarComunicacaoTest().ToString(), "Communication Test");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void Home_Load(object sender, EventArgs e)
        {
            Version vsr = Assembly.GetEntryAssembly().GetName().Version;
            this.Text = string.Format("Exemplo Hiro C# v.{0}.{1}.{2}", vsr.Major, vsr.Minor, vsr.Revision);
        }

        private void btPreset_Click(object sender, EventArgs e)
        {
            try
            {
                var ret = this.exemplo.Preset("1", 100);
                MessageBox.Show(ret.ToString(), "Preset");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void button5_Click(object sender, EventArgs e)
        {
            try
            {
                string msg = "";
                var ret = this.exemplo.GetVersaoConcentradorTest();
                if (ret != null)
                {
                    msg = string.Format(
                        "Número Série:\t{0}\n"+
                        "Versão Firmware:\t{1}\n" +
                        "Versão Protocolo:\t{2}", 
                        ret.NumeroSerie, ret.FirmwareAplicativo, ret.Protocolo);
                }
                MessageBox.Show(msg, "Hardware");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void button3_Click(object sender, EventArgs e)
        {
            try
            {
                string msg = "";
                var ret = this.exemplo.GetStatusBico(1);
                if (ret != null)
                {
                    //string status = ret.Status.ToString();
                    msg = String.Format(
                        "Status:\t{0}\n" +
                        "Cartão:\t{1}",
                        ret.Status.ToString(),
                        ret.Cartao.Codigo);
                }
                MessageBox.Show(msg, "Status Bico 1");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void button7_Click(object sender, EventArgs e)
        {
            try
            {
                string msg = "";
                var ret = this.exemplo.GetStatusBico(2);
                if (ret != null)
                {
                    //string status = ret.Status.ToString();
                    msg = String.Format(
                        "Status:\t{0}\n" +
                        "Cartão:\t{1}",
                        ret.Status.ToString(),
                        ret.Cartao.Codigo);
                }
                MessageBox.Show(msg, "Status Bico 2");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void button6_Click(object sender, EventArgs e)
        {
            try
            {
                string msg = "";
                var ret = this.exemplo.GetStatusTodosBicos();
                if (ret != null)
                {
                    msg = ret;
                    if (ret.Length > 32)
                    {
                        msg = "";
                        int k = 0, pos;
                        while (true)
                        {
                            if (k > 0) msg += "\n";
                            if (ret.Length >= 32)
                                pos = 32;
                            else
                                pos = ret.Length;
                            msg += ret.Substring(0, pos);
                            k = 1;
                            if (pos < 32) break;
                            ret = ret.Substring(pos);
                        }
                    }
                }
                MessageBox.Show(msg, "Status Todos Bicos");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void btnAbsPAF_Click(object sender, EventArgs e)
        {
            try
            {
                string msg = "Nenhum abastecimento.";
                var ret = this.exemplo.GetAbsPAFECF();
                if (ret != null)
                {
                    //string status = ret.Status.ToString();
                    msg = String.Format(
                        "Bico:\t\t{0}\n" +
                        "Valor Abast.:\t{1:N2}\n" +
                        "Litros Abast:\t{2:N2}\n" +
                        "Valor Uni:\t\t{3:N2}\n" +
                        "Ini. Litros:\t\t{4}\n" +
                        "Enc. Litros:\t{5}\n" +
                        "Data:\t\t{6:dd/MM/yyyy HH:mm:ss}\n" +
                        "Funcionário:\t{7}\n" +
                        "Cliente:\t\t{8}\n" +
                        "Veículo:\t\t{9}\n" +
                        "Motorista:\t\t{10}\n" +
                        "Endereço:\t\t{11}\n" +
                        "Status:\t\t{12}",
                        ret.Bico.Numero,
                        ret.ValorAbastecido, ret.LitrosAbastecidos,
                        ret.ValorPorLitro,
                        ret.Bico.EncerranteLitroInicial, ret.Bico.EncerranteLitro,
                        ret.DataHora,
                        ret.CartaoFuncionario.Endereco, ret.CartaoCliente.Endereco, ret.CartaoVeiculo.Endereco,
                        ret.CartaoMotorista.Endereco, ret.Endereco,
                        ret.Status.ToString());
                }
                MessageBox.Show(msg, "Abastecimento PAFECF");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }

        private void button4_Click(object sender, EventArgs e)
        {
            try
            {
                string msg = "";
                var ret = this.exemplo.GetConfiguracaoServidorSMTPTest();
                msg = String.Format("Servidor: {0}\nPorta: {1}", ret.Endereco, ret.Porta);
                MessageBox.Show(msg, "Servidor SMTP");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.StackTrace);
            }
        }
    }
}
